Wokkel 18.0.0
=============

|pypi|
|travis|


What is this?
-------------

Wokkel is a Python module for experimenting with future enhancements to Twisted
Words, that should eventually be included in the main Twisted main development
tree. Some of the code in Wokkel has already made that transition, but is still
included to be used with older Twisted releases.


Requirements
------------

- Python 2.7, Python 3.4 or later, or pypy equivalent
- Twisted 15.5.0 or later for Python 2
- Twisted 16.4.0 or later for Python 3
- python-dateutil
- incremental 16.9.0 or later


Resources
---------

Wokkel has a `home <https://wokkel.ik.nu/>`_ and `documentation <https://wokkel.ik.nu/documentation/>`_.

Besides the general Twisted resources, help is available on the
`Twisted-Jabber mailing list <https://mailman.ik.nu/mailman/listinfo/twisted-jabber>`_.


Copyright and Warranty
----------------------

The code in this distribution is Copyright (c) Ralph Meijer, unless
explicitly specified otherwise.

Wokkel is made available under the MIT License. The included
`LICENSE <LICENSE>`_ file describes this in detail.


Contributors
------------

- Christopher Zorn
- Jack Moffitt
- Mike Malone
- Pablo Martín
- Fabio Forno
- Kandaurov Oleg
- Jérôme Poisson
- Ilja Braude
- Alexey Bezhan
- Mayank Singh
- Adrien Cossa


Author
------

Ralph Meijer
<mailto:ralphm@ik.nu>
<xmpp:ralphm@ik.nu>


Name
----

Wokkel lends it name from a popular twisted savory snack in the Netherlands.


.. |pypi| image:: http://img.shields.io/pypi/v/wokkel.svg
.. _pypi: https://pypi.python.org/pypi/wokkel

.. |travis| image:: https://travis-ci.org/ralphm/wokkel.svg?branch=master
.. _travis: https://travis-ci.org/ralphm/wokkel
